# Documentation for `Switch`
::: photonai.base.Switch
    selection:
      members:
        - __init__
        - __iadd__
        - add
        - fit
        - predict
        - transform
        - predict_proba
